@@ -28,12 +28,6 @@ module test;
 
   reg reset_done;
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut);
-  end
-
-
   initial begin
     CLK = 0;
     forever begin
