@@ -254,7 +254,7 @@ module main
   assign myaxi_arprot = 0;
   assign myaxi_arqos = 0;
   assign myaxi_aruser = 0;
-  reg [32-1:0] outstanding_wreq_count_0;
+  reg [3-1:0] outstanding_wcount_0;
   assign myaxi_rready = 0;
   reg [32-1:0] fsm;
   localparam fsm_init = 0;
@@ -264,14 +264,14 @@ module main
   wire [32-1:0] _dataflow_counter_odata_1;
   wire _dataflow_counter_ovalid_1;
   wire _dataflow_counter_oready_1;
-  assign _dataflow_counter_oready_1 = (counter_1 > 0) && (myaxi_wready || !myaxi_wvalid);
+  assign _dataflow_counter_oready_1 = (counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid);
   reg _myaxi_cond_1_1;
   reg [32-1:0] sum;
   reg _seq_cond_0_1;
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wreq_count_0 <= 0;
+      outstanding_wcount_0 <= 0;
       myaxi_araddr <= 0;
       myaxi_arlen <= 0;
       myaxi_arvalid <= 0;
@@ -295,11 +295,11 @@ module main
         myaxi_wlast <= 0;
         last_2 <= 0;
       end 
-      if(myaxi_awvalid && myaxi_awready && !(myaxi_bvalid && myaxi_bready)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 + 1;
+      if(myaxi_wlast && myaxi_wvalid && myaxi_wready && !(myaxi_bvalid && myaxi_bready) && (outstanding_wcount_0 < 7)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
       end 
-      if(!(myaxi_awvalid && myaxi_awready) && (myaxi_bvalid && myaxi_bready) && (outstanding_wreq_count_0 > 0)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 - 1;
+      if(!(myaxi_wlast && myaxi_wvalid && myaxi_wready) && (myaxi_bvalid && myaxi_bready) && (outstanding_wcount_0 > 0)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
       end 
       myaxi_araddr <= 0;
       myaxi_arlen <= 0;
@@ -317,14 +317,14 @@ module main
       if(myaxi_awvalid && !myaxi_awready) begin
         myaxi_awvalid <= myaxi_awvalid;
       end 
-      if(_dataflow_counter_ovalid_1 && ((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid)) && ((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0))) begin
+      if(_dataflow_counter_ovalid_1 && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid)) && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0))) begin
         myaxi_wdata <= _dataflow_counter_odata_1;
         myaxi_wvalid <= 1;
         myaxi_wlast <= 0;
         myaxi_wstrb <= { 4{ 1'd1 } };
         counter_1 <= counter_1 - 1;
       end 
-      if(_dataflow_counter_ovalid_1 && ((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid)) && ((counter_1 > 0) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0)) && (counter_1 == 1)) begin
+      if(_dataflow_counter_ovalid_1 && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid)) && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0)) && (counter_1 == 1)) begin
         myaxi_wlast <= 1;
         last_2 <= 1;
       end 
